PercentTouchScaleResolver class

A TouchScaleResolver that provides a fixed scale value.

Inheritance

Constructors

PercentTouchScaleResolver()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
transform(Size size, double scale) double
Calculates the scale to apply based on the intrinsic widget size.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited