rejectBehavior property
Defines how the gesture is rejected based on pointer movement.
Implementation
final TouchScaleRejectBehavior? rejectBehavior;
Defines how the gesture is rejected based on pointer movement.
final TouchScaleRejectBehavior? rejectBehavior;