resolver property
Resolves the scale factor to apply during a press interaction.
Values below 1.0 shrink the widget, and values above 1.0 expand it.
Implementation
final TouchScaleResolver? resolver;
Resolves the scale factor to apply during a press interaction.
Values below 1.0 shrink the widget, and values above 1.0 expand it.
final TouchScaleResolver? resolver;