rejectBehavior property
The behavior used to reject a gesture based on pointer movement.
Implementation
final TouchScaleRejectBehavior? rejectBehavior;
The behavior used to reject a gesture based on pointer movement.
final TouchScaleRejectBehavior? rejectBehavior;